Enum fixed_width::DeserializeError[][src]

pub enum DeserializeError {
    Message(String),
    Unsupported(String),
    UnexpectedEndOfRecord,
    InvalidUtf8(Utf8Error),
    ParseBoolError(ParseBoolError),
    ParseIntError(ParseIntError),
    ParseFloatError(ParseFloatError),
}

Errors that occur during deserialization.

Variants

General error message as a String.

The desired type is unsupported by this deserializer.

The number of Fields given were less than the number of values to be deserialized.

The bytes given were not valid UTF-8.

A boolean value could not be parsed for this field.

An integer value could not be parsed for this field.

A float value could not be parsed for this field.