[−][src]Struct fixed_width::Writer
A fixed width data writer. It writes data provided in iterators to any type that implements io::Write.
Example
Writing a Vec<String> to a file:
extern crate fixed_width; use std::io::Write; use fixed_width::Writer; let data = vec![ "1234".to_string(), "5678".to_string(), ]; let mut wrtr = Writer::from_memory(); wrtr.write_iter(data.iter()); wrtr.flush();
Methods
impl<W> Writer<W> where
W: Write, [src]
W: Write,
pub fn from_writer(wrtr: W) -> Self[src]
Creates a new writer from any type that implements io::Write
pub fn from_buffer(buf: BufWriter<W>) -> Self[src]
Creates a new writer from a io::BufWriter that wraps a type that implements io::Write
pub fn write_serialized<T: FixedWidth + Serialize>(
&mut self,
records: impl Iterator<Item = T>
) -> Result<()>[src]
&mut self,
records: impl Iterator<Item = T>
) -> Result<()>
Writes the given iterator of FixedWidth + Serialize types to the underlying writer,
optionally inserting linebreaks if specified.
pub fn write_iter<T: AsByteSlice>(
&mut self,
records: impl Iterator<Item = T>
) -> Result<()>[src]
&mut self,
records: impl Iterator<Item = T>
) -> Result<()>
Writes the given iterator of types that implement AsByteSlice to the underlying writer, optionally inserting linebreaks if specified.
pub fn write_linebreak(&mut self) -> Result<()>[src]
Writes the linebreak specified to the underlying writer. Does nothing if there is no linebreak.
pub fn linebreak(self, linebreak: LineBreak) -> Self[src]
Sets the linebreak desired for this data. Defaults to LineBreak::None.
impl Writer<Vec<u8>>[src]
pub fn from_memory() -> Self[src]
Creates a new writer in memory from a Vec<u8>.