Enum fixed_width::DeserializeError [−][src]
pub enum DeserializeError {
Message(String),
Unsupported(String),
UnexpectedEndOfRecord,
InvalidUtf8(Utf8Error),
ParseBoolError(ParseBoolError),
ParseIntError(ParseIntError),
ParseFloatError(ParseFloatError),
}Errors that occur during deserialization.
Variants
Message(String)General error message as a String.
Unsupported(String)The desired type is unsupported by this deserializer.
UnexpectedEndOfRecordThe number of Fields given were less than the number of values to be deserialized.
InvalidUtf8(Utf8Error)The bytes given were not valid UTF-8.
ParseBoolError(ParseBoolError)A boolean value could not be parsed for this field.
ParseIntError(ParseIntError)An integer value could not be parsed for this field.
ParseFloatError(ParseFloatError)A float value could not be parsed for this field.